@@ -39,9 +39,15 @@ public:
   Dialog_Connection(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
   virtual ~Dialog_Connection();
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   sharedptr<SharedConnection> connect_to_server_with_connection_settings() const;
+#else
+  sharedptr<SharedConnection> connect_to_server_with_connection_settings(std::auto_ptr<ExceptionConnection>& error) const;
+#endif
 
   virtual void load_from_document(); //override
+  
+  void set_self_hosted_user_and_password(const Glib::ustring& username, const Glib::ustring& password);
 
   /** Use this to override the data from load_from_document().
    * For instance, if you want to try to connect to a renamed database.
