@@ -426,16 +426,18 @@ void Box_Data_List::on_adddel_user_changed(const Gtk::TreeModel::iterator& row,
           {
             //Get the value of the corresponding key in the current table (that identifies the record in the table that we will change)
             sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
-            layout_item->set_name(relationship->get_from_field());
+            layout_item->set_full_field_details( document->get_field(relationship->get_from_table(), relationship->get_from_field()) );
 
             primary_key_value = get_entered_field_data(layout_item);
 
-            const bool test = add_related_record_for_field(layout_field, relationship, primary_key_field, primary_key_value);
+            //Note: This just uses an existing record if one already exists:
+            Gnome::Gda::Value primary_key_value_used;
+            const bool test = add_related_record_for_field(layout_field, relationship, primary_key_field, primary_key_value, primary_key_value_used);
             if(!test)
               return;
 
             //Get the new primary_key_value if it has been created:
-            primary_key_value = get_entered_field_data(layout_item);
+            primary_key_value = primary_key_value_used;
 
             //Now that the related record exists, the following code to set the value of the other field in the related field can succeed.
           }
